@@ -1,10 +1,10 @@
 use std::{fs, path::PathBuf};
-use swc_common::{chain, Mark, DUMMY_SP};
+use swc_common::{chain, Mark};
 use swc_ecma_ast::*;
 use swc_ecma_parser::{EsConfig, Parser, StringInput, Syntax, TsConfig};
 use swc_ecma_transforms_base::resolver::resolver_with_mark;
 use swc_ecma_transforms_testing::test_fixture;
-use swc_ecma_visit::{as_folder, Node, Visit, VisitMutWith, VisitWith};
+use swc_ecma_visit::{as_folder, VisitMut, VisitMutWith};
 use swc_webpack_ast::reducer::ast_reducer;
 
 #[testing::fixture("tests/fixture/**/input.js")]
@@ -21,7 +21,8 @@ fn fixture(input: PathBuf) {
 
             chain!(
                 resolver_with_mark(top_level_mark),
-                as_folder(ast_reducer(top_level_mark))
+                as_folder(ast_reducer(top_level_mark)),
+                as_folder(AssertValid)
             )
         },
         &input,
@@ -31,14 +32,20 @@ fn fixture(input: PathBuf) {
 
 struct AssertValid;
 
-impl Visit for AssertValid {
-    fn visit_invalid(&mut self, i: &Invalid, _: &dyn Node) {
+impl VisitMut for AssertValid {
+    fn visit_mut_invalid(&mut self, i: &mut Invalid) {
         panic!("found invalid: {:?}", i)
     }
 
-    fn visit_empty_stmt(&mut self, i: &EmptyStmt, _: &dyn Node) {
+    fn visit_mut_empty_stmt(&mut self, i: &mut EmptyStmt) {
         panic!("found empty: {:?}", i)
     }
+
+    fn visit_mut_ident(&mut self, i: &mut Ident) {
+        if i.span.is_dummy() {
+            panic!("found an identifier with dummy span: {:?}", i)
+        }
+    }
 }
 
 #[testing::fixture("../swc_ecma_parser/tests/typescript/tsc/**/input.ts")]
@@ -78,7 +85,7 @@ fn assert_no_invalid(input: PathBuf) {
 
         module.visit_mut_with(&mut pass);
         dbg!(&module);
-        module.visit_with(&Invalid { span: DUMMY_SP }, &mut AssertValid);
+        module.visit_mut_with(&mut AssertValid);
 
         Ok(())
     })
